; ##############################################################################
; ##############################################################################
; ##############################################################################
;																				
; Timer 0+1+2 berlauf-Int aktivieren (Timer/Counter Interrupt Mask)			
;																				
; TIMSK ==> OCIE2 TOIE2 TICIE1 OCIE1A OCIE1B TOIE1 R TOIE0  					
;																				
TIMER_AKTIVIEREN:
	ldi temp,(0<<OCIE2)|(0<<TOIE2)|(0<<TICIE1)|(0<<OCIE1A)|(0<<OCIE1B)|(0<<TOIE1)|(1<<TOIE0)
	out TIMSK,temp       
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
; TIMER0 (8Bit) Vorteiler														
;																				
; CS02 CS01 CS00 	Description													
;	0 	0 	0 		No clock source (Timer/Counter stopped).					
;	0 	0 	1 		clkI/O/		(No prescaling)									
;	0 	1 	0 		clkI/O/8 	(From prescaler)								
; *	0 	1 	1 		clkI/O/64 	(From prescaler)								
; 	1 	0 	0 		clkI/O/256 	(From prescaler)								
; 	1 	0 	1 		clkI/O/1024 (From prescaler)								
;	1 	1 	0 		External clock source on T0 pin. Clock on falling edge.		
;	1 	1 	1 		External clock source on T0 pin. Clock on rising edge.		
; TIMER-WERTE (2 hoch 8  minus...)												
TIMER0_INITIALISIERUNG:

.equ TIMERWERT0 			=256-4	

	ldi temp,(0<<CS02)|(1<<CS01)|(1<<CS00)
	OUT TCCR0,temp

	ldi temp, TIMERWERT0; TIMER0 Startwert		
	out TCNT0,temp
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
TIM0_OVF:
	push TEMP		    ; Sichern von "TEMP" im Stack
	in	 TEMP,SREG		; Einlesen des SREG 
	push TEMP	    	; Schreiben von  SREG  im Stack (KOPIE)
	push TEMP1
	push ZL
	push ZH
;-------------------------------------------------------------------------------
	ldi temp, TIMERWERT0; TIMER0 Startwert					
	out TCNT0,temp
;-------------------------------------------------------------------------------
; Tasten Abfrage																
TIM0_TA:
	LDS temp,(adr_TASTE)
	tst temp
	brne TIM0_NOTA
	; Taste "M"gedrckt ?		
	sbis (TASTE_M_PIN),(TASTE_M_PIN_NR)				; springe, wenn BIT(PIN) high	
	SBR temp,(TASTE_MENUE)
	; Taste "B"gedrckt ?		
	sbis (TASTE_E_PIN),(TASTE_E_PIN_NR)				; springe, wenn BIT(PIN) high	
	SBR temp,(TASTE_ENTER)
	STS(adr_TASTE),temp
	ldi ZL,low (1000); Tastensperre
	ldi ZH,high(1000)
	STS (adr_VT_L),ZL
	STS (adr_VT_H),ZH
TIM0_NOTA:
;-------------------------------------------------------------------------------
	rcall DIGIT
	rcall PWM
;-------------------------------------------------------------------------------
	pop ZH
	pop ZL
	pop TEMP1
	pop	TEMP			; LESEN von SREG vom STACK (KOPIE)
	out	SREG,TEMP		; Wiederherstellen von SREG
	pop	TEMP			; Wiederherstellen von "TEMP" 			
reti
; ##############################################################################
; ##############################################################################
; ##############################################################################
PWM:
	LDS temp1,(adr_PWM_COUNTER)
	inc temp1
	STS(adr_PWM_COUNTER),temp1
	LDS temp,(adr_PWM_IST)
	cp temp,temp1
	breq PWM_AUS
	breq PWM_AUS
	brsh PWM_EIN
;-------------------------------------------------------------------------------
PWM_AUS:
	PWM_OFF
	ret
;-------------------------------------------------------------------------------
PWM_EIN:
	PWM_ON
	ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
DIGIT:
	LDS temp,(adr_LED_ZAEHLER)
	cpi temp,0
	breq DIGIT_0
	cpi temp,1
	breq DIGIT_1
	cpi temp,2
	breq DIGIT_2
	cpi temp,3
	breq DIGIT_3
	cpi temp,4
	breq DIGIT_4
	rjmp DIGIT_5
; ------------------------------------------------------------------------------
DIGIT_0:
	LDS temp,(adr_LED_ZAEHLER)	; ZHLER+1		
	inc temp
	STS(adr_LED_ZAEHLER),temp 
	DIGIT_5_OFF
	LDS temp,(adr_LED_BYTE_0)
	tst temp
	breq DIGIT_1
	rcall SEGMENT7_BALKEN
	DIGIT_0_ON
	ret
; ------------------------------------------------------------------------------
DIGIT_1:
	LDS temp,(adr_LED_ZAEHLER)	; ZHLER+1		
	inc temp
	STS(adr_LED_ZAEHLER),temp 
	DIGIT_0_OFF
	LDS temp,(adr_LED_BYTE_1)
	tst temp
	breq DIGIT_2
	rcall SEGMENT7_BALKEN
	DIGIT_1_ON
	ret
; ------------------------------------------------------------------------------
DIGIT_2:
	LDS temp,(adr_LED_ZAEHLER)	; ZHLER+1		
	inc temp
	STS(adr_LED_ZAEHLER),temp 
	DIGIT_1_OFF
	LDS temp,(adr_LED_BYTE_2)
	tst temp
	breq DIGIT_3
	rcall SEGMENT7_BALKEN
	DIGIT_2_ON
	ret
; ------------------------------------------------------------------------------
DIGIT_3:
	LDS temp,(adr_LED_ZAEHLER)	; ZHLER+1		
	inc temp
	STS(adr_LED_ZAEHLER),temp 
	DIGIT_2_OFF
	LDS temp,(adr_LED_BYTE_3)
	rcall SEGMENT7_BALKEN
	DIGIT_3_ON
	ret
; ------------------------------------------------------------------------------
DIGIT_4:
	LDS temp,(adr_LED_ZAEHLER)	; ZHLER+1		
	inc temp
	STS(adr_LED_ZAEHLER),temp 
	DIGIT_3_OFF
	LDS temp,(adr_LED_BYTE_4)
	tst temp
	breq DIGIT_5
	rcall SEGMENT7_BALKEN
	DIGIT_4_ON
	ret
; ------------------------------------------------------------------------------
DIGIT_5:
	STS(adr_LED_ZAEHLER),NULL
	DIGIT_4_OFF
	LDS temp,(adr_LED_BYTE_5)
	tst temp
	brne DIGIT_5w
	ret
DIGIT_5w:
	rcall SEGMENT7_BALKEN
	DIGIT_5_ON
	ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
SEGMENT7_BALKEN:

	SBRC temp,0	; Skip if Bit in Register Cleared
	A_ON
	SBRS temp,0	; Skip if Bit in Register is Set
	A_OFF


	SBRC temp,1
	B_ON
	SBRS temp,1
	B_OFF


	SBRC temp,2
	C_ON
	SBRS temp,2
	C_OFF


	SBRC temp,3
	D_ON
	SBRS temp,3
	D_OFF


	SBRC temp,4
	E_ON
	SBRS temp,4
	E_OFF



	SBRC temp,5
	F_ON
	SBRS temp,5
	F_OFF


	SBRC temp,6
	G_ON
	SBRS temp,6
	G_OFF


	SBRC temp,7
	P_ON
	SBRS temp,7
	P_OFF
ret
; ##############################################################################
; ##############################################################################
; ##############################################################################
